{% extends 'board_base.html' %}
{% load i18n %}
{% load mptt_tags %}
{% load forum_tags %}

{% block sub-title %}{% trans "Index" %}{% endblock sub-title %}

{% block content %}
	<br />
	<div class="row">
		<div class="forumlist-top-controls col-xs-12">
			{% if request.user.is_authenticated %}
				<div class="pull-right">
					<a href="{% url 'forum_tracking:mark_all_forums_read' %}" class="btn btn-link"><i class="fa fa-check-circle-o">&nbsp;</i>{% trans "Mark forums read" %}</a>
				</div>
				<a href="{% url 'forum_tracking:unread_topics' %}" class="btn btn-link">{% trans "View unread topics" %}</a>
			{% endif %}
		</div>
	</div>
    {% forum_list forums %}
    <h4 class="page-header">{% trans "Statistics" %}</h4>
    <p class="statistics">{% trans "Total posts:" %}&nbsp;<b>{{ total_posts_count }}</b>&nbsp;&#8226;&nbsp;{% trans "Total topics:" %}&nbsp;<b>{{ total_topics_count }}</b>&nbsp;</p>
{% endblock content %}