{% extends 'board_base.html' %}
{% load i18n %}
{% load forum_conversation_tags %}

{{% block sub-title %}{% trans "Unlock topic" %}{% endblock sub-title %}

{% block content %}
	<div class="row">
		<div class="col-xs-12">
			<div class="panel panel-default topic-unlock">
	            <div class="panel-heading">
	                <h3 class="panel-title">{% trans "Unlock topic" %}</h3>
	            </div>
	            <div class="panel-body">
	            	<div class="warning-message">{% trans "Are you sure you want to unlock this topic?" %}</div>
				    <form action="" method="post">{% csrf_token %}
				        <input type="hidden" name="post" value="yes" />
				        <input type="submit" value="{% trans "Yes" %}" class="btn btn-warning" />
				        <a href="{% url 'forum_conversation:topic' topic.forum.slug topic.forum.pk topic.slug topic.pk %}" class="btn">{% trans "No" %}</a>
				    </form>
	            </div>
			</div>
		</div>
	</div>
{% endblock content %}