//
// Variables
// --------------------------------------------------


//== Global values
//
//## Some global values used in all styles are defined here.

@baseUrl: '../';


// Default colors
//
// ## Some default colors...

@black:                 #000;
@blue:                  #049cdb;
@blue-dark:             #0064cd;
@gray:                  #555;
@gray-dark:             #333;
@gray-darker:           #222;
@gray-light:            #999;
@gray-lighter:          #eee;
@green:                 #46a546;
@green-light:			#7ac143;
@orange:                #f89406;
@pink:                  #c3325f;
@purple:                #7a43b6;
@red:                   #9d261d;
@red-light:             #B82010;
@white:                 #fff;
@yellow:                #ffc40d;
