//
// MACHINA BOARD: COMMON STYLES
// --------------------------------------------------


.navbar-fixed-top-spacing{
	height: 90px;
}

.navbar.machina-navbar{
	.navbar-form{
		.input-group{
			width: 100%;
		}
	}
}

#main_container{
	margin-bottom: 40px;

	.controls-link-wrapper{
		margin-top: -20px;
    padding-top: 9px;
	}
}
