//
// MACHINA ADMIN: FORUM CHANGE LIST STYLES
// --------------------------------------------------


.danger{
    color: @red-light;
}
a.danger{
    color: @red-light;
    &:hover{
        color: @red;
    }
}

.success{
    color: @green-light;
}
a.success{
    color: @green-light;
    &:hover{
        color: @green;
    }
}

#forum-table-dnd{
    .quick-actions-cell{
        width: 5%;
        text-align: center;

        .disabled{
            color: @gray-lighter;
        }
    }
}
