# -*- coding: utf-8 -*-

# Standard library imports
# Third party imports
# Local application / specific library imports


default_app_config = 'machina.apps.forum_member.registry_config.MemberRegistryConfig'
