//
// MACHINA DJANGO ADMIN UNIQUE STYLES
// --------------------------------------------------


// Core variables and mixins
@import "variables.less";

// Components
@import "../_libs/font-awesome/less/font-awesome.less";

// Unique
@import "admin_pages/forum_change_list.less";
@import "admin_pages/forum_permissions.less";
