// Forum_search.less
// Variables to customize the look and feel of machina search stuf
// ---------------------------------------------------------------


.resultslist{
    margin-bottom: 6px;

    .panel-heading{
        padding-top: 10px;
        padding-left: 14px;
        padding-right: 0;
        padding-bottom: 8px;
    }

    .panel-body{
        padding: 0;

        table.table{
            margin: 0 auto;

            td{
                padding-top: 2px;
                padding-bottom: 2px;
                vertical-align: middle !important;
            }

            td.post-name{width: 40%;}
            td.post-content{width:60%;}
        }

        .post-name{
            .post-created{
                font-size: 11px;
                color: #666;
            }
        }

        .post-content{
        	.highlighted{
        		font-weight: bold;
        	}
        }
    }
}