// Member_profile.less
// Variables to customize the look and feel of machina forum profiles
// ------------------------------------------------------------------


.profile-sidebar{
	.panel{
		override: hidden;

		.profile-avatar{
			&.empty{
				height: 150px;
				background: @gray-lighter;
				text-align: center;

				i.fa{
					margin-top: 50px;
				}
			}

			img{
				width: 100%;
			}
		}
	}
}

.recent-posts{
	.panel-body{
		padding-top: 0;
		padding-bottom: 0;

		.post{
			margin-bottom: 0;
			padding-top: 10px;
			border-bottom: 4px solid @gray-lighter;

			.post-title{
				font-size: 16px;
			}
		}
	}
}
