//
// MACHINA ADMIN: FORUM PERMISSION STYLES
// --------------------------------------------------



table#forum-permissions-table-dnd{
    width: 100%;

    .permission-name-cell{
    	width: 70%;
    }
    .not-set-cell, .granted-cell, .not-granted-cell{
    	width: 10%;
    	text-align: center;
    }

    thead th{
    	a{
    		padding: 0;
    		display: block;
    	}
    }

    tbody td{
      &.permission-scope-wrapper{
        padding: 10px 15px;
        background: #f6f6f6;
        font-size: 12px;
        text-transform: uppercase;
        color: @gray-light;
      }

    	&.granted-cell{
    		padding: 0;

    		&:hover, &:focus{
    			background: @green;
    		}
    	}
    	&.not-granted-cell{
    		padding: 0;

    		&:hover, &:focus{
    			background: @red;
    		}
    	}
    	&.not-set-cell{
    		padding: 0;

    		&:hover, &:focus{
    			background: @gray-light;
    		}
    	}
    	&.permission-name-cell{
    		font-weight: bold;

    		.text{
    			padding: 3px 5px;
    		}
    	}

    	label{
    		padding: 0;
    		width: 100%;
    	}

    	input{
    		margin: 0;
    		width: 100%;
    		height: 30px;
    		cursor: pointer;
    	}
    }
}
