// Forum_lists.less
// Variables to customize the look and feel of machina topic lists
// ---------------------------------------------------------------


.pagination-block{
    text-align: right;
    vertical-align: middle;

    .mark-topics-read{
        padding: 8px 12px;
        float: right;
    }

    .pagination{
        margin: 4px 0;
        float: right;
    }
}

.forum-actions-block{
    position: relative;
    z-index: 2;
    padding-top: 3px;
    padding-bottom: 9px;

    p{
        margin: 0;
        padding: 6px 12px;
    }
}

.topiclist{
    margin-bottom: 6px;

    .panel-heading{
        padding-top: 10px;
        padding-left: 0;
        padding-right: 0;
        padding-bottom: 8px;

        .panel-row{
            margin: 0;
        }

        .topic-count-col{
            text-align: center;
        }

        .topic-count-col, .topic-last-post-col{
            font-size: 13px;
            text-transform: uppercase;
            color: @gray;
        }
    }

    .panel-body{
        padding: 0;

        .panel-row{
            margin: 0;
            padding-top: 10px;
            padding-bottom: 5px;
            border-bottom: 1px solid @gray-lighter;
        }

        .topic-icon{
            position: relative;
            padding-left: 5px;
            padding-right: 20px;
            width: 50px;
            text-align: center;
            color: lighten(@blue-dark, 20%);

            &.unread{
                color: lighten(@red, 20%);
            }

            .locked-indicator{
                position: absolute;
                right: 18px;
                bottom: 2px;
                color: @red;
            }
        }

        .topic-name{
            .topic-created, .topic-inline-pagination{
                font-size: 11px;
                color: #666;
            }

            .topic-inline-pagination{
                padding-top: 6px;
            }
        }

        .topic-count{
            text-align: center;
        }

        .topic-count, .topic-last-post{
            font-size: 13px;
        }
    }
}