// moderation.less
// Variables to customize the look and feel of machina moderation pages
// -------------------------------------------------------------------


.topic-lock, .topic-unlock, .topic-delete, .topic-move, .topic-update-type{
	margin-top: 15px;
    margin-bottom: 8px;

    .warning-message{
        margin-bottom: 10px;
    }
}

.postmoderationlist{
    margin-bottom: 6px;

    .panel-heading{
        padding-top: 10px;
        padding-left: 0;
        padding-right: 0;
        padding-bottom: 8px;

        .panel-row{
            margin: 0;
        }

        .moderation-col{
            font-size: 13px;
            text-align: center;
            text-transform: uppercase;
            color: @gray;
        }
    }

    .panel-body{
        padding: 0;

        .panel-row{
            margin: 0;
            padding-top: 10px;
            padding-bottom: 5px;
            border-bottom: 1px solid @gray-lighter;
        }

        .post-name{
            .post-created{
                font-size: 11px;
                color: #666;
            }
        }

        .topic-name, .forum-name{
        	text-align: center;

        	a{
        		margin-top: 3px;
        		display: inline-block;
        	}
        }

        .post-mark{
        	text-align: center;

        	input{
        		margin-top: 5px;
        		display: inline-block;
        	}
        }
    }
}