# -*- coding: utf-8 -*-

# Standard library imports
# Third party imports
# Local application / specific library imports
from machina.apps.forum_conversation.forum_attachments.abstract_models import AbstractAttachment


class Attachment(AbstractAttachment):
    pass
