// Forum_lists.less
// Variables to customize the look and feel of machina topic lists
// ---------------------------------------------------------------


.pagination-block{
    text-align: right;

    .pagination{
        margin: 4px 0;
    }
}

.topic-actions-block{
    position: relative;
    z-index: 2;
    padding-top: 3px;
    padding-bottom: 9px;

    .moderation-dropdown{
        margin-left: 4px;
        display: inline-block;
    }
}

.post{
    margin-bottom: 8px;

    .panel-body{
        .post-content-wrapper{
            h4.subject{
                margin: 0;

                &:hover{
                  a{
                    display: inline-block;
                  }
                }

                a{
                  display: none;

                  &:hover, &:focus{
                    text-decoration: none;
                  }
                }
            }

            .attachments{
                .attachments-title{
                    margin-top: 10px;
                    display: inline-block;
                    border-bottom: 1px solid @gray-light;
                }

                .attachment{
                    margin-top: 4px;

                    p{
                        margin: 0;
                    }
                }
            }

            .post-signature{
                margin-top: 20px;
                margin-bottom: 20px;
                padding-top: 5px;
                border-top: 1px dashed @gray-lighter;
            }
        }

        .post-sidebar{
            border-left: 1px solid @gray-lighter;

            .avatar{
                margin-bottom: 6px;
            }
        }
    }
}

.poll{
    margin-bottom: 8px;

    .panel-body{
        .poll-content-wrapper{
            h4.question{
                margin: 0;
            }

            hr{
                margin-top: 5px;
                margin-bottom: 10px;
            }

            .poll-options{
                margin-top: 16px;

                .radio, .checkbox{
                    margin: 0;
                }
            }
        }

    }
}
