{% extends 'board_base.html' %}
{% load i18n %}
{% load forum_conversation_tags %}

{% block sub-title %}{% trans "Post a new topic" %}{% endblock sub-title %}

{% block content %}
    <div class="row">
        <div class="col-xs-12">
            <h1>{{ forum.name }}</h1>
        </div>
    </div>
    {% if poll_preview %}
        {% include "forum_conversation/forum_polls/poll_preview.html" %}
    {% endif %}
    {% if preview %}
        {% include "forum_conversation/post_preview.html" %}
    {% endif %}
    <div class="row">
        <div class="col-xs-12">
            <div class="panel panel-default post-edit">
                <div class="panel-heading">
                    <h3 class="panel-title">{% trans "Post a new topic" %}</h3>
                </div>
                <div class="panel-body">
                    {% include "forum_conversation/partials/topic_form.html" %}
                </div>
            </div>
        </div>
    </div>
{% endblock content %}

{% block onbodyload %}
    machina.poll.init();
    machina.attachment.init();
{% endblock onbodyload %}

{% block extra_css %}
    {{ post_form.media.css }}
{% endblock extra_css %}

{% block extra_js %}
    {{ post_form.media.js }}
{% endblock extra_js %}
