<div id="messages">
{% if messages %}
    {% for message in messages %}
    <div class="alert alert-{{ message.tags }} {% if 'error' in message.tags %}alert-danger{% endif %} fade in">
            <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
            {% if 'noicon' not in message.tags %}
                {# Include an icon by default #}
                {% if 'success' in message.tags %}
                    <i class="icon-ok-sign"></i>
                {% endif %}
                {% if 'info' in message.tags %}
                    <i class="icon-info-sign"></i>
                {% endif %}
                {% if 'warning' in message.tags %}
                    <i class="icon-warning-sign"></i>
                {% endif %}
                {% if 'error' in message.tags %}
                    <i class="icon-exclamation-sign"></i>
                {% endif %}
            {% endif %}

            {{ message }}
        </div>
    {% endfor %}
{% endif %}
</div>
