{% load i18n %}

<!DOCTYPE html>
<html {% get_current_language as LANGUAGE_CODE %}lang="{{ LANGUAGE_CODE }}">
    <head>
        {% block head %}
            <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
            <meta name="viewport" content="width=device-width, maximum-scale=1.0">

            <title>{% block title %}{{ site.name }}{% endblock %}</title>
            <meta name="created" content="{% now "jS M Y h:i" %}" />
            <meta name="description" content="{% block meta_description %}{% endblock meta_description %}" />
            <meta name="keywords" content="{% block meta_keywords %}{% endblock meta_keywords %}"/>

            <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
            <!--[if lt IE 9]>
                <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
            <![endif]-->
        {% endblock head %}

        {% block css %}
        {% endblock css %}

        {% block extra_css %}
        {% endblock extra_css %}

    </head>
    <body>
        {% block js %}
        {% endblock js %}

        {% block body %}
            {# The forum content will go in this 'body' block #}
        {% endblock body %}

        {% block extra_js %}
        {% endblock extra_js %}
    </body>
</html>
