// Forum_lists.less
// Variables to customize the look and feel of machina forum lists
// ---------------------------------------------------------------


.forumlist-top-controls{
    padding-bottom: 9px;

    p{
        margin: 0;
        padding: 6px 12px;
    }
}

.forumlist{
    .panel-heading{
        padding-top: 10px;
        padding-left: 0;
        padding-right: 0;
        padding-bottom: 8px;

        .panel-row{
            margin: 0;
        }

        .forum-count-col{
            text-align: center;
        }

        .forum-count-col, .forum-last-post-col{
            font-size: 13px;
            text-transform: uppercase;
            color: @gray;
        }
    }

    .panel-body{
        padding: 0;

        .panel-row{
            margin: 0;
            padding-top: 10px;
            padding-bottom: 5px;
            border-bottom: 1px solid @gray-lighter;
        }

        .forum-icon{
            padding-left: 5px;
            padding-right: 20px;
            width: 50px;
            height: 45px;
            line-height: 49px;
            text-align: center;
            color: lighten(@blue-dark, 20%);

            &.unread{
                color: lighten(@red, 20%);
            }

            &.link{
                color: @gray-light;
            }
        }

        .forum-image{
            padding-right: 10px;
            height: 70px;
            line-height: 70px;

            img{
                vertical-align: middle;
            }
        }

        .forum-name{
            .forum-description{font-size: 11px;}
            .sub-forums{font-size: 12px;}
        }

        .forum-count, .forum-syndication{
            height: 45px;
            line-height: 45px;
            text-align: center;
        }

        .forum-last-post{
            padding-top: 5px;
        }

        .forum-count, .forum-last-post, .forum-link-redirects{
            font-size: 13px;
        }
    }
}
