// Post_edit.less
// Variables to customize the look and feel of machina post edit forms
// -------------------------------------------------------------------


.preview{
    .post-preview{
        .post-content-wrapper{
            hr{
                margin-top: 5px;
                margin-bottom: 10px;
            }
        }
    }
}

.post-edit{
    margin-bottom: 8px;

    form{
        .markItUp{
            width: 100%;

            textarea.markItUpEditor{
                width: 100%;
                font-familly: initial !important;
                font-size: 14px !important;
            }

            .markItUpHeader ul li{
                margin-bottom: 5px;
            }
        }

        #poll_formset{
            .poll-option-form{
                div.checkbox{
                    margin-top: 6px;
                }
            }
        }

        #attachment_formset{
            .attachments-title{
                margin-bottom: 10px;
            }

            .attachment-form{
                div.checkbox{
                    margin-top: 30px;
                }
            }
        }
    }
}

.post-delete{
    margin-top: 15px;
    margin-bottom: 8px;

    .warning-message{
        margin-bottom: 10px;
    }
}

.topic-review{
    .panel-body{
        max-height: 300px;
        overflow-y: scroll;

        .post-review{
            padding: 8px 0;
            border-bottom: 3px solid @gray-lighter;

            .post-content-wrapper{
                h4.subject{
                    margin: 0;
                }

                .attachments{
                    .attachments-title{
                        margin-top: 10px;
                        display: inline-block;
                        border-bottom: 1px solid @gray-light;
                    }

                    .attachment{
                        margin-top: 4px;

                        p{
                            margin: 0;
                        }
                    }
                }
            }

            .post-sidebar{
                border-left: 1px solid @gray-lighter;
            }
            }
    }
}